"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.apiRequest = exports.handleError = exports.instance = void 0;

var _axios = _interopRequireDefault(require("axios"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

var getEnv = function getEnv() {
  return process.env.NODE_ENV ? process.env.NODE_ENV : "development";
};

var getApiUrl = function getApiUrl(prodUrl, devUrl) {
  switch (getEnv()) {
    case "production":
      return prodUrl;

    case "development":
    default:
      return devUrl;
  }
};

var instance = function instance(prodUrl, devUrl) {
  return _axios.default.create({
    baseURL: getApiUrl(prodUrl, devUrl)
  });
};
/**
 * handleError - function to handle api request errors
 * @param {Function} dispatch - react-redux dispatch func
 * @param {Object|String} error - error message
 * @param {String} actionType - action type constant
 */


exports.instance = instance;

var handleError = function handleError(dispatch, error, actionType) {
  return dispatch({
    type: "".concat(actionType, "_ERROR"),
    error: error.response.data.errors
  });
};
/**
 * apiRequest - generic function to make a request with axios
 *
 * @param {Function} dispatch - react-redux's dispatch func
 * @param {String} requestType - type of http request
 * @param {String} actionType - type of action to be dispatched
 * @param {Object} - options (endpoint, data, requireAuth)
 *
 * @returns {Promise}
 */


exports.handleError = handleError;

var apiRequest =
/*#__PURE__*/
function () {
  var _ref = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee(api, dispatch) {
    var opts,
        requestArgs,
        response,
        _args = arguments;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            opts = _args.length > 2 && _args[2] !== undefined ? _args[2] : {};
            _context.prev = 1;
            dispatch({
              type: "".concat(opts.actionType, "_REQUEST")
            });
            requestArgs = ["".concat(opts.endpoint || "")];

            if (opts.requestType === "post" || opts.requestType === "put") {
              requestArgs.push(opts.data || {});
            }

            _context.next = 7;
            return api[opts.requestType].apply(api, _toConsumableArray(opts.requestArgs));

          case 7:
            response = _context.sent;
            dispatch({
              type: "".concat(actionType, "_SUCCESS"),
              payload: response.data
            });
            return _context.abrupt("return", Promise.resolve(response.data));

          case 12:
            _context.prev = 12;
            _context.t0 = _context["catch"](1);
            throw _context.t0;

          case 15:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[1, 12]]);
  }));

  return function apiRequest(_x, _x2) {
    return _ref.apply(this, arguments);
  };
}();

exports.apiRequest = apiRequest;